<?php
namespace User\Entity;

use Doctrine\ORM\Mapping as ORM;



/**
 * Permissions for a system user.
 *
 * @ORM\Entity
 * @ORM\HasLifecycleCallbacks
 * @ORM\Table(name="profile_permissions_override")
 */
class Override
{

	/**
	 * Can archive records.
	 */
	const ARCHIVE = true;
	/**
	 * Pull Synchronization Strategy for this table.
	 */
	const PULL_SYNCH_STRATEGY = false;
	/**
	 * Push Synchronization Strategy for this table.
	 */
	const PUSH_SYNCH_STRATEGY = false;

	/**
	 * @ORM\Id
	 * @ORM\Column(type="integer");
	 * @ORM\GeneratedValue(strategy="AUTO")
	 */
	protected $id;

	/**
	 * @ORM\ManyToOne(targetEntity="Profile")
	 * @ORM\JoinColumn(name="profile_id")
	 **/
	protected $profile;

	/**
	 * @ORM\ManyToOne(targetEntity="Permissions")
	 * @ORM\JoinColumn(name="permission_id")
	 **/
	protected $permissions;

	/* -----------------------  SECTIONS   ----------------------- */
	/**
	 * @ORM\Column(type="boolean", name="access_admin_module")
	 */
	protected $accessAdminModule  = 0;
	/**
	 * @ORM\Column(type="boolean", name="access_portal_module")
	 */
	protected $accessPortalModule = 0;

	/* ----------------------- MY SETTINGS ----------------------- */
	/**
	 * @ORM\Column(type="boolean", name="settings_page")
	 */
	protected $settingsPage = 0;
	/**
	 * @ORM\Column(type="boolean", name="settings_user")
	 */
	protected $settingsUser = 0;
	/**
	 * @ORM\Column(type="boolean", name="settings_club")
	 */
	protected $settingsClub = 0;
	/**
	 * @ORM\Column(type="boolean", name="settings_membership")
	 */
	protected $settingsMembership = 0;
	/**
	 * @ORM\Column(type="boolean", name="settings_retail")
	 */
	protected $settingsRetail = 0;
	/**
	 * @ORM\Column(type="boolean", name="settings_report")
	 */
	protected $settingsReport = 0;
	/**
	 * @ORM\Column(type="boolean", name="settingsHpi_report")
	 */
	protected $settingsHpiReport = 0;
	/**
	 * @ORM\Column(type="boolean", name="settings_grid_export")
	 */
	protected $settingsGridExport = 0;
	/**
	 * @ORM\Column(type="boolean", name="settings_dealership")
	 */
	protected $settingsDealership = 0;
	/**
	 * @ORM\Column(type="boolean", name="settings_personal")
	 */
	protected $settingsPersonal = 0;
	/**
	 * @ORM\Column(type="boolean", name="settings_reset_pin")
	 */
	protected $settingsResetPin = 0;

	/* ----------------------- VALUATION ----------------------- */
	/**
	 * @ORM\Column(type="boolean", name="valuation_page")
	 */
	protected $valuationPage = 0;
	/**
	 * @ORM\Column(type="boolean", name="valuation_view")
	 */
	protected $valuationView = 0;
	/**
	 * @ORM\Column(type="boolean", name="valuation_archive")
	 */
	protected $valuationArchive = 0;
	/**
	 * @ORM\Column(type="boolean", name="valuation_unarchive")
	 */
	protected $valuationUnarchive = 0;
	/**
	 * @ORM\Column(type="boolean", name="valuation_create_new")
	 */
	protected $valuationCreateNew = 0;
	/**
	 * @ORM\Column(type="boolean", name="valuation_create_sales")
	 */
	protected $valuationCreateSales = 0;
	/**
	 * @ORM\Column(type="boolean", name="valuation_create_pending")
	 */
	protected $valuationCreatePending = 0;
	/**
	 * @ORM\Column(type="boolean", name="valuation_create_priceguide")
	 */
	protected $valuationCreatePriceguide = 0;
	/**
	 * @ORM\Column(type="boolean", name="valuation_create_complete")
	 */
	protected $valuationCreateComplete = 0;
	/**
	 * @ORM\Column(type="boolean", name="valuation_create_stock")
	 */
	protected $valuationCreateStock = 0;
	/**
	 * @ORM\Column(type="boolean", name="valuation_update")
	 */
	protected $valuationUpdate = 0;
	/**
	 * @ORM\Column(type="boolean", name="valuation_route_pending")
	 */
	protected $valuationRoutePending = 0;
	/**
	 * @ORM\Column(type="boolean", name="valuation_route_complete")
	 */
	protected $valuationRouteComplete = 0;
	/**
	 * @ORM\Column(type="boolean", name="valuation_route_stock")
	 */
	protected $valuationRouteStock = 0;
	/**
	 * @ORM\Column(type="boolean", name="valuation_route_priceguide")
	 */
	protected $valuationRoutePriceguide = 0;
	/**
	 * @ORM\Column(type="boolean", name="valuation_is_sales")
	 */
	protected $valuationIsSales = 0;
	/**
	 * @ORM\Column(type="boolean", name="valuation_is_valuator")
	 */
	protected $valuationIsValuator = 0;
	/**
	 * @ORM\Column(type="boolean", name="valuation_print")
	 */
	protected $valuationPrint = 0;
	/**
	 * @ORM\Column(type="boolean", name="valuation_b4c_report")
	 */
	protected $valuationB4cReport = 0;
	/**
	 * @ORM\Column(type="boolean", name="valuation_bmw_report")
	 */
	protected $valuationBmw = 0;
	/**
	 * @ORM\Column(type="boolean", name="valuation_route_deal_done")
	 */
	protected $valuationRouteDealDone = 0;
	/**
	 * @ORM\Column(type="boolean", name="valuation_route_deal_not_done")
	 */
	protected $valuationRouteDealNotDone = 0;
	/**
	 * @ORM\Column(type="boolean", name="valuation_grid_export")
	 */
	protected $valuationGridExport = 0;
	/**
	 * @ORM\Column(type="boolean", name="valuation_update_damages")
	 */
	protected $valuationUpdateDamages = 0;
	/**
	 * @ORM\Column(type="boolean", name="valuation_upload_photos")
	 */
	protected $valuationUploadPhotos = 0;
	/**
	 * @ORM\Column(type="boolean", name="valuation_pricing_details")
	 */
	protected $valuationPricingDetails = 0;

	/**
	 * @ORM\Column(type="boolean", name="valuation_update_cover_received")
	 */
	protected $valuationUpdateCoverReceived = 0;

    /**
     * @ORM\Column(type="boolean", name="valuation_calendar")
     */
    protected $valuationCalendar = 0;
	
	/* ----------------------- PRICE GUIDE ----------------------- */
	/**
	 * @ORM\Column(type="boolean", name="pg_page")
	 */
	protected $pgPage = 0;
	/**
	 * @ORM\Column(type="boolean", name="pg_b4c_report")
	 */
	protected $pgB4cReport = 0;
	/**
	 * @ORM\Column(type="boolean", name="pg_view")
	 */
	protected $pgView = 0;
	/**
	 * @ORM\Column(type="boolean", name="pg_make_offer")
	 */
	protected $pgMakeOffer = 0;
	/**
	 * @ORM\Column(type="boolean", name="pg_update_offer")
	 */
	protected $pgUpdateOffer = 0;
	/**
	 * @ORM\Column(type="boolean", name="pg_print")
	 */
	protected $pgPrint = 0;
	/**
	 * @ORM\Column(type="boolean", name="pg_grid_export")
	 */
	protected $pgGridExport = 0;
	/**
	 * @ORM\Column(type="boolean", name="pg_archive")
	 */
	protected $pgArchive = 0;
	/**
	 * @ORM\Column(type="boolean", name="pg_un_archive")
	 */
	protected $pgUnArchive = 0;

	/* ----------------------- AUCTION ----------------------- */
	/**
	 * @ORM\Column(type="boolean", name="auction_page")
	 */
	protected $auctionPage = 0;
	/**
	 * @ORM\Column(type="boolean", name="auction_create")
	 */
	protected $auctionGridExport = 0;
	/**
	 * @ORM\Column(type="boolean", name="auction_bid")
	 */
	protected $auctionBid = 0;

	/* ----------------------- TRADE CENTER ----------------------- */
	/**
	 * @ORM\Column(type="boolean", name="tradecenter_page")
	 */
	protected $tcPage = 0;
	/**
	 * @ORM\Column(type="boolean", name="tradecenter_grid_export")
	 */
	protected $tcGridExport = 0;

	/* ----------------------- STOCK ----------------------- */
	/**
	 * @ORM\Column(type="boolean", name="stock_page")
	 */
	protected $stockPage = 0;
	/**
	 * @ORM\Column(type="boolean", name="stock_create")
	 */
	protected $stockCreate = 0;
	/**
	 * @ORM\Column(type="boolean", name="stock_view")
	 */
	protected $stockView = 0;
	/**
	 * @ORM\Column(type="boolean", name="stock_route_auction")
	 */
	protected $stockRouteAuction = 0;
	/**
	 * @ORM\Column(type="boolean", name="stock_route_retail")
	 */
	protected $stockRouteRetail = 0;
	/**
	 * @ORM\Column(type="boolean", name="stock_reclaim_retail")
	 */
	protected $stockReclaimRetail = 0;
	/**
	 * @ORM\Column(type="boolean", name="stock_route_priceguide")
	 */
	protected $stockRoutePriceguide = 0;
	/**
	 * @ORM\Column(type="boolean", name="stock_route_valuation")
	 */
	protected $stockRouteValuation = 0;
	/**
	 * @ORM\Column(type="boolean", name="stock_print")
	 */
	protected $stockPrint = 0;
	/**
	 * @ORM\Column(type="boolean", name="stock_archive")
	 */
	protected $stockArchive = 0;
	/**
	 * @ORM\Column(type="boolean", name="stock_unarchive")
	 */
	protected $stockUnarchive = 0;
	/**
	 * @ORM\Column(type="boolean", name="stock_update")
	 */
	protected $stockUpdate = 0;
	/**
	 * @ORM\Column(type="boolean", name="stock_grid_export")
	 */
	protected $stockGridExport = 0;

    /**
     * @ORM\Column(type="boolean", name="stock_auction_report_export")
     */
    protected $stockAuctionReportGridExport = 0;

    /**
     * @ORM\Column(type="boolean", name="stock_bulk_import_drive")
     */
    protected $stockBulkImportDrive = 0;

    /**
     * @ORM\Column(type="boolean", name="stock_bulk_import_pinnacle")
     */
    protected $stockBulkImportPinnacle = 0;

	/**
	 * @ORM\Column(type="boolean", name="stock_update_damages")
	 */
	protected $stockUpdateDamages = 0;
	
	/**
	 * @ORM\Column(type="boolean", name="stock_update_cover_received")
	 */
	protected $stockUpdateCoverReceived = 0;
	
	/**
	 * @ORM\Column(type="boolean", name="stock_upload_photos")
	 */
	protected $stockUploadPhotos = 0;

	/* ----------------------- APP ----------------------- */
	/**
	 * @ORM\Column(type="boolean", name="app_create_valuation")
	 */
	protected $appCreateValuation = 0;
	/**
	 * @ORM\Column(type="boolean", name="app_complete_valuation")
	 */
	protected $appCompleteValuation = 0;

	/* ----------------------- ADMIN ----------------------- */
	/**
	 * @ORM\Column(type="boolean", name="admin_page")
	 */
	protected $adminPage = 0;
	/**
	 * @ORM\Column(type="boolean", name="admin_registration")
	 */
	protected $adminRegistration = 0;
	/**
	 * @ORM\Column(type="boolean", name="admin_report")
	 */
	protected $adminReport = 0;
	/**
	 * @ORM\Column(type="boolean", name="admin_dealer")
	 */
	protected $adminDealer = 0;
	/**
	 * @ORM\Column(type="boolean", name="admin_communication")
	 */
	protected $adminCommunication = 0;
	/**
	 * @ORM\Column(type="boolean", name="admin_settings")
	 */
	protected $adminSettings = 0;
	/**
	 * @ORM\Column(type="boolean", name="admin_user")
	 */
	protected $adminUser = 0;
	/**
	 * @ORM\Column(type="boolean", name="admin_auction")
	 */
	protected $adminAuction = 0;
  /**
	 * @ORM\Column(type="boolean", name="historical_page")
	 */
	protected $historicalPage = 0;

	/* --------------------- SU Options ------------------- */
	/**
	 * @ORM\Column(type="boolean", name="su_access")
	 */
	protected $suAccess = 0;
	/**
	 * @ORM\Column(type="boolean", name="su_group_full")
	 */
	protected $suGroupFull = 0;
	/**
	 * @ORM\Column(type="boolean", name="su_division_full")
	 */
	protected $suDivisionFull = 0;
	/**
	 * @ORM\Column(type="boolean", name="su_company_full")
	 */
	protected $suCompanyFull = 0;

    /* --------------------- Export Data ------------------- */

    /**
     * @ORM\Column(type="boolean", name="etp_gem_dmd")
     */
    protected $etpGemDmd = 0;

	/* --------------------- Tracking ------------------- */
	/**
	 * @ORM\Column(type="datetime");
	 */
	protected $created;

	/**
	 * @ORM\Column(type="datetime", nullable=true);
	 */
	protected $updated;

	/**
	 * @ORM\Column(type="boolean");
	 */
	protected $archived = false;

	/**
	 * Magic getter to expose protected properties.
	 *
	 * @param string $property
	 * @return mixed
	 */
	public function __get($property)
	{
		return $this->$property;
	}

	/**
	 * Magic setter to save protected properties.
	 * @param string $property
	 * @param mixed $value
	 */
	public function __set($property, $value)
	{
		$this->$property = $value;
	}

	/**
	 * @ORM\PrePersist
	 */
	public function setCreateTime()
	{
		$this->created = new \DateTime("now");
	}

	/**
	 * @ORM\PreUpdate
	 */
	public function setUpdateTime()
	{
		$this->updated = new \DateTime("now");
	}

	/**
	 * Convert the object to an array.
	 * @return array
	 */
	public function toArray(array $expand = array())
	{
		return array(
				'id' 						=> $this->id,
				'accessAdminModule' 		=> $this->accessAdminModule,
				'accessPortalModule' 		=> $this->accessPortalModule,
				'settingsPage' 				=> $this->settingsPage,
				'settingsUser' 				=> $this->settingsUser,
				'settingsClub' 				=> $this->settingsClub,
				'settingsMembership' 		=> $this->settingsMembership,
				'settingsRetail' 			=> $this->settingsRetail,
				'settingsReport' 			=> $this->settingsReport,
				'settingsHpiReport' 		=> $this->settingsHpiReport,
				'settingsGridExport' 		=> $this->settingsGridExport,
				'settingsDealership' 		=> $this->settingsDealership,
				'settingsPersonal' 			=> $this->settingsPersonal,
				'settingsResetPin' 			=> $this->settingsResetPin,
				'valuationPage' 			=> $this->valuationPage,
				'valuationView' 			=> $this->valuationView,
				'valuationArchive' 			=> $this->valuationArchive,
				'valuationUnarchive' 		=> $this->valuationUnarchive,
				'valuationCreateNew' 		=> $this->valuationCreateNew,
				'valuationCreateSales' 		=> $this->valuationCreateSales,
				'valuationCreatePending'	=> $this->valuationCreatePending,
				'valuationCreatePriceguide'	=> $this->valuationCreatePriceguide,
				'valuationCreateComplete'	=> $this->valuationCreateComplete,
				'valuationCreateStock'		=> $this->valuationCreateStock,
				'valuationUpdate'			=> $this->valuationUpdate,
				'valuationRoutePending'		=> $this->valuationRoutePending,
				'valuationRouteComplete'	=> $this->valuationRouteComplete,
				'valuationRouteStock'		=> $this->valuationRouteStock,
				'valuationRoutePriceguide'	=> $this->valuationRoutePriceguide,
				'valuationIsSales'			=> $this->valuationIsSales,
				'valuationIsValuator'		=> $this->valuationIsValuator,
				'valuationPrint'			=> $this->valuationPrint,
				'valuationB4cReport'		=> $this->valuationB4cReport,
				'valuationBmw'				=> $this->valuationBmw,
				'valuationRouteDealDone'	=> $this->valuationRouteDealDone,
				'valuationRouteDealNotDone'	=> $this->valuationRouteDealNotDone,
				'valuationGridExport'		=> $this->valuationGridExport,
				'valuationUpdateDamages'	=> $this->valuationUpdateDamages,
				'valuationUpdateCoverReceived'	=> $this->valuationUpdateCoverReceived,
				'valuationUploadPhotos'		=> $this->valuationUploadPhotos,
				'valuationPricingDetails'	=> $this->valuationPricingDetails,
                'valuationCalendar'	        => $this->valuationCalendar,
				'pgPage' 					=> $this->pgPage,
				'pgB4cReport' 				=> $this->pgB4cReport,
				'pgView' 					=> $this->pgView,
				'pgMakeOffer'	 			=> $this->pgMakeOffer,
				'pgUpdateOffer' 			=> $this->pgUpdateOffer,
				'pgPrint' 					=> $this->pgPrint,
				'pgGridExport' 				=> $this->pgGridExport,
				'pgArchive' 				=> $this->pgArchive,
				'pgUnArchive' 				=> $this->pgUnArchive,
				'auctionPage' 				=> $this->auctionPage,
				'auctionGridExport' 		=> $this->auctionGridExport,
				'auctionBid' 				=> $this->auctionBid,
				'tcPage' 					=> $this->tcPage,
				'tcGridExport' 				=> $this->tcGridExport,
				'stockPage' 				=> $this->stockPage,
				'stockCreate' 				=> $this->stockCreate,
				'stockView' 				=> $this->stockView,
				'stockRouteAuction' 		=> $this->stockRouteAuction,
				'stockRouteRetail' 			=> $this->stockRouteRetail,
				'stockReclaimRetail' 		=> $this->stockReclaimRetail,
				'stockRoutePriceguide' 		=> $this->stockRoutePriceguide,
				'stockRouteValuation' 		=> $this->stockRouteValuation,
				'stockPrint' 				=> $this->stockPrint,
				'stockArchive' 				=> $this->stockArchive,
				'stockUnarchive' 			=> $this->stockUnarchive,
				'stockUpdate' 				=> $this->stockUpdate,
				'stockGridExport' 			=> $this->stockGridExport,
                'stockAuctionReportGridExport' 			=> $this->stockAuctionReportGridExport,
                'stockBulkImportDrive' 		=> $this->stockBulkImportDrive,
                'stockBulkImportPinnacle' 	=> $this->stockBulkImportPinnacle,
				'stockUpdateDamages' 		=> $this->stockUpdateDamages,
				'stockUpdateCoverReceived' 		=> $this->stockUpdateCoverReceived,
				'stockUploadPhotos' 		=> $this->stockUploadPhotos,
				'appCreateValuation' 		=> $this->appCreateValuation,
				'appCompleteValuation' 		=> $this->appCompleteValuation,
				'adminPage' 				=> $this->adminPage,
				'adminRegistration' 		=> $this->adminRegistration,
				'adminReport' 				=> $this->adminReport,
				'adminCommunication' 		=> $this->adminCommunication,
				'adminSettings' 			=> $this->adminSettings,
				'adminUser' 				=> $this->adminUser,
				'adminAuction' 				=> $this->adminAuction,
				'adminDealer' 				=> $this->adminDealer,
				'suAccess' 					=> $this->suAccess,
				'suGroupFull' 				=> $this->suGroupFull,
				'suDivisionFull' 			=> $this->suDivisionFull,
				'suCompanyFull' 			=> $this->suCompanyFull,
                'historicalPage' 			=> $this->historicalPage,
                'etpGemDmd' 			    => $this->etpGemDmd
		);
	}

	/**
	 * Convert the object to an array.
	 * @return array
	 */
	public function fromArray(array $data)
	{
			isset($data['accessAdminModule'])
				&& $this->accessAdminModule			= $data['accessAdminModule'];
			isset($data['accessPortalModule'])
				&& $this->accessPortalModule		= $data['accessPortalModule'];
			isset($data['settingsPage'])
				&& $this->settingsPage 				= $data['settingsPage'];
			isset($data['settingsUser'])
				&& $this->settingsUser 				= $data['settingsUser'];
			isset($data['settingsClub'])
				&& $this->settingsClub 				= $data['settingsClub'];
			isset($data['settingsMembership'])
				&& $this->settingsMembership 		= $data['settingsMembership'];
			isset($data['settingsRetail'])
				&& $this->settingsRetail 			= $data['settingsRetail'];
			isset($data['settingsReport'])
				&& $this->settingsReport 			= $data['settingsReport'];
			isset($data['settingsHpiReport'])
				&& $this->settingsHpiReport 		= $data['settingsHpiReport'];
			isset($data['settingsGridExport'])
				&& $this->settingsGridExport 		= $data['settingsGridExport'];
			isset($data['settingsDealership'])
				&& $this->settingsDealership 		= $data['settingsDealership'];
			isset($data['settingsPersonal'])
				&& $this->settingsPersonal 			= $data['settingsPersonal'];
			isset($data['settingsResetPin'])
				&& $this->settingsResetPin 			= $data['settingsResetPin'];
			isset($data['valuationPage'])
				&& $this->valuationPage 			= $data['valuationPage'];
			isset($data['valuationView'])
				&& $this->valuationView 			= $data['valuationView'];
			isset($data['valuationArchive'])
				&& $this->valuationArchive 			= $data['valuationArchive'];
			isset($data['valuationUnarchive'])
				&& $this->valuationUnarchive 		= $data['valuationUnarchive'];
			isset($data['valuationCreateNew'])
				&& $this->valuationCreateNew 		= $data['valuationCreateNew'];
			isset($data['valuationCreateSales'])
				&& $this->valuationCreateSales 		= $data['valuationCreateSales'];
			isset($data['valuationCreatePending'])
				&& $this->valuationCreatePending 	= $data['valuationCreatePending'];
			isset($data['valuationCreatePriceguide'])
				&& $this->valuationCreatePriceguide	= $data['valuationCreatePriceguide'];
			isset($data['valuationCreateComplete'])
				&& $this->valuationCreateComplete 	= $data['valuationCreateComplete'];
			isset($data['valuationCreateStock'])
				&& $this->valuationCreateStock 		= $data['valuationCreateStock'];
			isset($data['valuationUpdate'])
				&& $this->valuationUpdate 			= $data['valuationUpdate'];
			isset($data['valuationRoutePending'])
				&& $this->valuationRoutePending 	= $data['valuationRoutePending'];
			isset($data['valuationRouteComplete'])
				&& $this->valuationRouteComplete 	= $data['valuationRouteComplete'];
			isset($data['valuationRouteStock'])
				&& $this->valuationRouteStock 		= $data['valuationRouteStock'];
			isset($data['valuationRoutePriceguide'])
				&& $this->valuationRoutePriceguide 	= $data['valuationRoutePriceguide'];
			isset($data['valuationIsSales'])
				&& $this->valuationIsSales 			= $data['valuationIsSales'];
			isset($data['valuationIsValuator'])
				&& $this->valuationIsValuator 		= $data['valuationIsValuator'];
			isset($data['valuationPrint'])
				&& $this->valuationPrint 			= $data['valuationPrint'];
			isset($data['valuationB4cReport'])
				&& $this->valuationB4cReport 		= $data['valuationB4cReport'];
			isset($data['valuationBmw'])
				&& $this->valuationBmw 				= $data['valuationBmw'];
			isset($data['valuationRouteDealDone'])
				&& $this->valuationRouteDealDone 	= $data['valuationRouteDealDone'];
			isset($data['valuationRouteDealNotDone'])
				&& $this->valuationRouteDealNotDone = $data['valuationRouteDealNotDone'];
			isset($data['valuationGridExport'])
				&& $this->valuationGridExport 		= $data['valuationGridExport'];
			isset($data['valuationUpdateDamages'])
				&& $this->valuationUpdateDamages	= $data['valuationUpdateDamages'];
			
			isset($data['valuationUpdateCoverReceived'])
				&& $this->valuationUpdateCoverReceived	= $data['valuationUpdateCoverReceived'];
			
			isset($data['valuationUploadPhotos'])
				&& $this->valuationUploadPhotos		= $data['valuationUploadPhotos'];
			isset($data['valuationPricingDetails'])
				&& $this->valuationPricingDetails	= $data['valuationPricingDetails'];

            isset($data['valuationCalendar'])
                && $this->valuationCalendar	= $data['valuationCalendar'];

			isset($data['pgPage'])
				&& $this->pgPage 					= $data['pgPage'];
			isset($data['pgB4cReport'])
				&& $this->pgB4cReport 				= $data['pgB4cReport'];
			isset($data['pgView'])
				&& $this->pgView 					= $data['pgView'];
			isset($data['pgMakeOffer'])
				&& $this->pgMakeOffer 				= $data['pgMakeOffer'];
			isset($data['pgUpdateOffer'])
				&& $this->pgUpdateOffer 			= $data['pgUpdateOffer'];
			isset($data['pgPrint'])
				&& $this->pgPrint 					= $data['pgPrint'];
			isset($data['pgGridExport'])
				&& $this->pgGridExport 				= $data['pgGridExport'];
			isset($data['pgArchive'])
				&& $this->pgArchive 				= $data['pgArchive'];
			isset($data['pgUnArchive'])
				&& $this->pgUnArchive 				= $data['pgUnArchive'];
			isset($data['auctionPage'])
				&& $this->auctionPage 				= $data['auctionPage'];
			isset($data['auctionGridExport'])
				&& $this->auctionGridExport 		= $data['auctionGridExport'];
			isset($data['auctionBid'])
				&& $this->auctionBid 				= $data['auctionBid'];
			isset($data['tcPage'])
				&& $this->tcPage 					= $data['tcPage'];
			isset($data['tcGridExport'])
				&& $this->tcGridExport 				= $data['tcGridExport'];
			isset($data['stockPage'])
				&& $this->stockPage 				= $data['stockPage'];
			isset($data['stockCreate'])
				&& $this->stockCreate 				= $data['stockCreate'];
			isset($data['stockView'])
				&& $this->stockView 				= $data['stockView'];
			isset($data['stockRouteAuction'])
				&& $this->stockRouteAuction 		= $data['stockRouteAuction'];
			isset($data['stockRouteRetail'])
				&& $this->stockRouteRetail 			= $data['stockRouteRetail'];
			isset($data['stockReclaimRetail'])
				&& $this->stockReclaimRetail 		= $data['stockReclaimRetail'];
			isset($data['stockRoutePriceguide'])
				&& $this->stockRoutePriceguide 		= $data['stockRoutePriceguide'];
			isset($data['stockRouteValuation'])
				&& $this->stockRouteValuation 		= $data['stockRouteValuation'];
			isset($data['stockPrint'])
				&& $this->stockPrint 				= $data['stockPrint'];
			isset($data['stockArchive'])
				&& $this->stockArchive 				= $data['stockArchive'];
			isset($data['stockUnarchive'])
				&& $this->stockUnarchive 			= $data['stockUnarchive'];
			isset($data['stockUpdate'])
				&& $this->stockUpdate 				= $data['stockUpdate'];
			isset($data['stockGridExport'])
				&& $this->stockGridExport 			= $data['stockGridExport'];
            isset($data['stockAuctionReportGridExport'])
                && $this->stockAuctionReportGridExport 			= $data['stockAuctionReportGridExport'];
            isset($data['stockBulkImportDrive'])
                && $this->stockBulkImportDrive 			= $data['stockBulkImportDrive'];
            isset($data['stockBulkImportPinnacle'])
                && $this->stockBulkImportPinnacle 			= $data['stockBulkImportPinnacle'];
			isset($data['stockUpdateDamages'])
				&& $this->stockUpdateDamages 		= $data['stockUpdateDamages'];
			
			isset($data['stockUpdateCoverReceived'])
				&& $this->stockUpdateCoverReceived 		= $data['stockUpdateCoverReceived'];
			
			isset($data['stockUploadPhotos'])
				&& $this->stockUploadPhotos 		= $data['stockUploadPhotos'];
			isset($data['appCreateValuation'])
				&& $this->appCreateValuation 		= $data['appCreateValuation'];
			isset($data['appCompleteValuation'])
				&& $this->appCompleteValuation 		= $data['appCompleteValuation'];
			isset($data['adminPage'])
				&& $this->adminPage 				= $data['adminPage'];
			isset($data['adminRegistration'])
				&& $this->adminRegistration 		= $data['adminRegistration'];
			isset($data['adminReport'])
				&& $this->adminReport 				= $data['adminReport'];
			isset($data['adminCommunication'])
				&& $this->adminCommunication 		= $data['adminCommunication'];
			isset($data['adminSettings'])
				&& $this->adminSettings 			= $data['adminSettings'];
			isset($data['adminUser'])
				&& $this->adminUser 				= $data['adminUser'];
			isset($data['adminAuction'])
				&& $this->adminAuction 				= $data['adminAuction'];
			isset($data['adminDealer'])
				&& $this->adminDealer 				= $data['adminDealer'];
			isset($data['suAccess'])
				&& $this->suAccess 					= $data['suAccess'];
			isset($data['suGroupFull'])
				&& $this->suGroupFull 				= $data['suGroupFull'];
			isset($data['suDivisionFull'])
				&& $this->suDivisionFull 			= $data['suDivisionFull'];
			isset($data['suCompanyFull'])
				&& $this->suCompanyFull 			= $data['suCompanyFull'];
            isset($data['historicalPage'])
                && $this->historicalPage 			= $data['historicalPage'];
            isset($data['etpGemDmd'])
                && $this->etpGemDmd 			= $data['etpGemDmd'];
	}
}